@@ -5,17 +5,17 @@ setMethod("elt", "EL", function(object,
                                 alpha = 0.05,
                                 calibrate = "chisq",
                                 control = el_control()) {
-  npar <- getNumPar(object)
   stopifnot(
-    "`elt()` method is not applicable to an empty model." = (npar != 0L),
+    "`elt()` is not applicable to an empty model." = getDF(object) >= 1L,
     "`object` has no `data`. Fit the model with `keep_data == TRUE`." =
-      (isFALSE(is.null(getData(object)))),
-    "Invalid `control` specified." = (is(control, "ControlEL"))
+      isFALSE(is.null(getData(object))),
+    "Invalid `control` specified." = is(control, "ControlEL")
   )
-  h <- validate_hypothesis(rhs, lhs, npar)
+  onames <- names(logProb(object))
+  pnames <- names(getOptim(object)$par)
+  h <- validate_hypothesis(rhs, lhs, getNumPar(object), pnames)
   alpha <- validate_alpha(alpha)
   calibrate <- validate_calibrate(calibrate)
-  nm <- names(getOptim(object)$par)
   method <- getMethodEL(object)
   maxit <- control@maxit
   maxit_l <- control@maxit_l
@@ -32,13 +32,15 @@ setMethod("elt", "EL", function(object,
     par <- h$r
     out <- compute_EL(method, par, getData(object), maxit_l, tol_l, th, w)
     optim <- validate_optim(out$optim)
-    names(optim$par) <- nm
-    p <- length(par)
-    cal <- calibrate(calibrate, alpha, out$statistic, p, par, object, control)
+    names(optim$par) <- pnames
+    cal <- calibrate(
+      calibrate, alpha, out$statistic, length(par), par, object, control
+    )
     return(new("ELT",
-      optim = optim, alpha = alpha, logl = out$logl, loglr = out$loglr,
-      statistic = out$statistic, cv = unname(cal["cv"]),
-      pval = unname(cal["pval"]), calibrate = calibrate
+      optim = optim, logp = setNames(out$logp, onames), logl = out$logl,
+      loglr = out$loglr, statistic = out$statistic, df = length(par),
+      pval = unname(cal["pval"]), cv = unname(cal["cv"]), rhs = par, lhs = h$l,
+      alpha = alpha, calibrate = calibrate
     ))
   }
   # Proceed with chi-square calibration for non-NULL `lhs`
@@ -53,11 +55,13 @@ setMethod("elt", "EL", function(object,
     step, th, w
   )
   optim <- validate_optim(out$optim)
-  names(optim$par) <- nm
+  names(optim$par) <- pnames
+  q <- nrow(h$l)
   new("ELT",
-    optim = optim, alpha = alpha, logl = out$logl, loglr = out$loglr,
-    statistic = out$statistic, cv = qchisq(1 - alpha, df = nrow(h$l)),
-    pval = pchisq(out$statistic, df = nrow(h$l), lower.tail = FALSE),
+    optim = optim, logp = setNames(out$logp, onames), logl = out$logl,
+    loglr = out$loglr, statistic = out$statistic, df = q,
+    pval = pchisq(out$statistic, df = q, lower.tail = FALSE),
+    cv = qchisq(1 - alpha, df = q), rhs = h$r, lhs = h$l, alpha = alpha,
     calibrate = calibrate
   )
 })
@@ -70,18 +74,18 @@ setMethod("elt", "QGLM", function(object,
                                   alpha = 0.05,
                                   calibrate = "chisq",
                                   control = el_control()) {
-  # `npar` includes the dispersion parameter
-  p <- getNumPar(object) - 1L
   stopifnot(
-    "`elt()` method is not applicable to an empty model." = (p != 0L),
+    "`elt()` is not applicable to an empty model." = getDF(object) >= 1L,
     "`object` has no `data`. Fit the model with `keep_data == TRUE`." =
-      (isFALSE(is.null(getData(object)))),
-    "Invalid `control` specified." = (is(control, "ControlEL"))
+      isFALSE(is.null(getData(object))),
+    "Invalid `control` specified." = is(control, "ControlEL")
   )
-  h <- validate_hypothesis(rhs, lhs, p)
+  # `npar` includes the dispersion parameter
+  onames <- names(logProb(object))
+  pnames <- names(getOptim(object)$par[-getNumPar(object)])
+  h <- validate_hypothesis(rhs, lhs, getNumPar(object) - 1L, pnames)
   alpha <- validate_alpha(alpha)
   calibrate <- validate_calibrate(calibrate)
-  nm <- names(getOptim(object)$par)
   method <- getMethodEL(object)
   maxit <- control@maxit
   maxit_l <- control@maxit_l
@@ -94,18 +98,22 @@ setMethod("elt", "QGLM", function(object,
     stopifnot(
       "F calibration is applicable only to the mean." = (calibrate != "f")
     )
-    par <- c(h$r, object@dispersion)
+    if (calibrate == "boot") {
+      par <- c(h$r, compute_dispersion(object, h$r))
+    } else {
+      par <- c(h$r, object@dispersion)
+    }
     out <- compute_EL(method, par, getData(object), maxit_l, tol_l, th, w)
     optim <- validate_optim(out$optim)
-    names(optim$par) <- nm
-    npar <- length(par)
+    names(optim$par) <- pnames
     cal <- calibrate(
-      calibrate, alpha, out$statistic, npar, par, object, control
+      calibrate, alpha, out$statistic, length(par), par, object, control
     )
     return(new("ELT",
-      optim = optim, alpha = alpha, logl = out$logl, loglr = out$loglr,
-      statistic = out$statistic, cv = unname(cal["cv"]),
-      pval = unname(cal["pval"]), calibrate = calibrate
+      optim = optim, logp = setNames(out$logp, onames), logl = out$logl,
+      loglr = out$loglr, statistic = out$statistic, df = length(par),
+      pval = unname(cal["pval"]), cv = unname(cal["cv"]), rhs = h$r, lhs = h$l,
+      alpha = alpha, calibrate = calibrate
     ))
   }
   stopifnot(
@@ -119,11 +127,13 @@ setMethod("elt", "QGLM", function(object,
     maxit_l, tol, tol_l, step, th, w
   )
   optim <- validate_optim(out$optim)
-  names(optim$par) <- nm
+  names(optim$par) <- pnames
+  q <- nrow(l)
   new("ELT",
-    optim = optim, alpha = alpha, logl = out$logl, loglr = out$loglr,
-    statistic = out$statistic, cv = qchisq(1 - alpha, df = nrow(l)),
-    pval = pchisq(out$statistic, df = nrow(l), lower.tail = FALSE),
+    optim = optim, logp = setNames(out$logp, onames), logl = out$logl,
+    loglr = out$loglr, statistic = out$statistic, df = q,
+    pval = pchisq(out$statistic, df = q, lower.tail = FALSE),
+    cv = qchisq(1 - alpha, df = q), rhs = h$r, lhs = h$l, alpha = alpha,
     calibrate = calibrate
   )
 })
@@ -136,17 +146,17 @@ setMethod("elt", "SD", function(object,
                                 alpha = 0.05,
                                 calibrate = "chisq",
                                 control = el_control()) {
-  npar <- getNumPar(object)
   stopifnot(
-    "`elt()` method is not applicable to an empty model." = (npar != 0L),
+    "`elt()` is not applicable to an empty model." = getDF(object) >= 1L,
     "`object` has no `data`. Fit the model with `keep_data == TRUE`." =
-      (isFALSE(is.null(getData(object)))),
-    "Invalid `control` specified." = (is(control, "ControlEL"))
+      isFALSE(is.null(getData(object))),
+    "Invalid `control` specified." = is(control, "ControlEL")
   )
-  h <- validate_hypothesis(rhs, lhs, npar)
+  onames <- names(logProb(object))
+  pnames <- names(getOptim(object)$par)
+  h <- validate_hypothesis(rhs, lhs, getNumPar(object), pnames)
   alpha <- validate_alpha(alpha)
   calibrate <- validate_calibrate(calibrate)
-  nm <- names(getOptim(object)$par)
   maxit_l <- control@maxit_l
   tol_l <- control@tol_l
   th <- control@th
@@ -162,12 +172,13 @@ setMethod("elt", "SD", function(object,
     )
     out <- compute_EL("sd", par, getData(object), maxit_l, tol_l, th, w)
     optim <- validate_optim(out$optim)
-    names(optim$par) <- nm
+    names(optim$par) <- pnames
     cal <- calibrate(calibrate, alpha, out$statistic, 1L, par, object, control)
     return(new("ELT",
-      optim = optim, alpha = alpha, logl = out$logl, loglr = out$loglr,
-      statistic = out$statistic, cv = unname(cal["cv"]),
-      pval = unname(cal["pval"]), calibrate = calibrate
+      optim = optim, logp = setNames(out$logp, onames), logl = out$logl,
+      loglr = out$loglr, statistic = out$statistic, df = 1L,
+      pval = unname(cal["pval"]), cv = unname(cal["cv"]), rhs = h$r, lhs = h$l,
+      alpha = alpha, calibrate = calibrate
     ))
   }
   stopifnot(
@@ -185,11 +196,12 @@ setMethod("elt", "SD", function(object,
   )
   out <- compute_EL("sd", par, getData(object), maxit_l, tol_l, th, w)
   optim <- validate_optim(out$optim)
-  names(optim$par) <- nm
+  names(optim$par) <- pnames
   new("ELT",
-    optim = optim, alpha = alpha, logl = out$logl, loglr = out$loglr,
-    statistic = out$statistic, cv = qchisq(1 - alpha, df = 1L),
+    optim = optim, logp = setNames(out$logp, onames), logl = out$logl,
+    loglr = out$loglr, statistic = out$statistic, df = 1L,
     pval = pchisq(out$statistic, df = 1L, lower.tail = FALSE),
+    cv = qchisq(1 - alpha, df = 1L), rhs = h$r, lhs = h$l, alpha = alpha,
     calibrate = calibrate
   )
 })
